Pipeline Overview
==================

The PUNCH data processing pipeline is implemented in three primary numbered levels, with an additional processing level for QuickPUNCH data. An overview of the data reduction pipeline is provided with details of orchestration, flows (including custom flows), and data handling. An overview of the various processing levels and modules within is also provided, broken down by level.
